;-------------------------------------------------------------------------------
; Name: support.asm
; Func: -
; Ver.: 1.0
; Date: 08-Mar-2004
; Auth: Andreas Dannenberg
;       MSP430 Applications
;       Texas Instruments Inc.
; Rem.: Build with Eclipse/MSP430
;-------------------------------------------------------------------------------
;			.cdecls C,LIST,"msp430x16x.h"
;-------------------------------------------------------------------------------
; Exported Symbols
;-------------------------------------------------------------------------------
            .def	DelayCycles
            .def 	WriteDWBE
;-------------------------------------------------------------------------------
; Implementation
;-------------------------------------------------------------------------------
			.text
;-------------------------------------------------------------------------------
; DelayCycles
;
; Delays the program flow by the given number of cycles (R12). The parameter
; MUST be >= 20 (decimal).
;
; IN:  R12
;-------------------------------------------------------------------------------
DelayCycles                                     ; call #DelayCycles (5 cyc)
            push    R12                         ; Save R12 (3 cyc)
            sub.w   #17,R12                     ; Adjust cycle count (2 cyc)
            clrc                                ; Clear carry bit (1 cyc)
            rrc.w   R12                         ; Divide by 2 (1 cyc)
            rra.w   R12                         ; Divide by 2 (1 cyc)
Delay2      nop                                 ; (1 cyc)
            dec.w   R12                         ; (1 cyc)
            jnz     Delay2                      ; (2 cyc)
            pop     R12                         ; Restore R12 (2 cyc)
            ret                                 ; (2 cyc)
;-------------------------------------------------------------------------------
; WriteDWBE
;
; Writes a DWORD to the given memory location in big-endian format. The
; memory address MUST be word-aligned.
;
; IN:  R12          Address
;      R13          Lower Word
;      R14          Upper Word
;-------------------------------------------------------------------------------
WriteDWBE
            swpb    R13                         ; Swap bytes in lower word
            swpb    R14                         ; Swap bytes in upper word
            mov.w   R14,0(R12)                  ; Write 1st word to memory
            mov.w   R13,2(R12)                  ; Write 2nd word to memory
            swpb    R13                         ; Restore R13
            swpb    R14                         ; Restore R14
            ret
;-------------------------------------------------------------------------------
			.end
